@@ -107,7 +107,7 @@ TIEXPORT1 int TICALL ticables_library_init(void)
 	HANDLE hDll;
 	int i;
 
-	hDll = GetModuleHandle("libticables2-5.dll");
+	hDll = GetModuleHandle("libticables2-6.dll");
 	GetModuleFileName(hDll, locale_dir, 65535);
 
 	for (i = strlen(locale_dir); i >= 0; i--)
@@ -138,8 +138,8 @@ TIEXPORT1 int TICALL ticables_library_init(void)
 #if defined(ENABLE_NLS)
 	ticables_info("setlocale: %s", setlocale(LC_ALL, ""));
 	ticables_info("bindtextdomain: %s", bindtextdomain(PACKAGE, locale_dir));
-	//bind_textdomain_codeset(PACKAGE, "UTF-8"/*"ISO-8859-15"*/);
-	ticables_info("textdomain: %s", textdomain(PACKAGE));
+	bind_textdomain_codeset(PACKAGE, "UTF-8"/*"ISO-8859-15"*/);
+	ticables_info("textdomain: %s", textdomain(NULL));
 #endif
 #ifdef __LINUX__
 	{
@@ -379,7 +379,7 @@ TIEXPORT1 CablePort TICALL ticables_get_port(CableHandle* handle)
  * ticables_handle_show:
  * @handle: the handle
  *
- * Show informations stored in the handle.
+ * Show information stored in the handle.
  *
  * Return value: always 0.
  **/
